rm(list=ls())
getwd()
setwd("") # SET YOUR WORKING DIRECTORY #

## load the Paruelo & Lauenroth (1996) dataset from file
paruelo_data <- read.table("paruelo.txt", header=T)
attach(paruelo_data)
names(paruelo_data)

## plot histograms of the C3 and LOG10_C3 variables
par(mfrow=c(2,2))
hist(C3,10)
log_10_C3 <- log(C3,10)
hist(log_10_C3,10)
log_C3 <- log(C3)
hist(log_C3,10)
SQRT_C3 <- sqrt(C3)
hist(SQRT_C3,10)
par(mfrow=c(1,1))

## to assess the potential for collinearity, we create a subset of the data
## containing only the potential predictor variables
subset_data <- data.frame(LAT, LONG, MAP, MAT, JJAMAP, DJFMAP)

## use the pairs() function to plot all the variables against each other
pairs(subset_data,panel=panel.smooth)

## generate a correlation matrix using the cor() function
cor(subset_data)

## create a full regression model and summarize the results
model <- lm(SQRT_C3 ~ MAP+MAT+LONG+LAT+JJAMAP+DJFMAP)
summary(model)

## use the vif() function to calculate the variance inflation factors
library(car)
vif(model)

## Based on the collinearity analysis, we decide to use only LAT and LOG as
## predictor variables and generate models for all of the various combinations
model1 <-lm(SQRT_C3~1)
model2 <- lm(SQRT_C3~LONG)
model3 <- lm(SQRT_C3~LAT)
model4 <- lm(SQRT_C3~LONG+LAT)
model5 <- lm(SQRT_C3~LONG+LAT+LONG:LAT)
model6 <- lm(SQRT_C3~LONG*LAT)

## NOTE: the LONG*LAT term is equivalent to LONG+LAT+LONG:LAT

##Inspect the models individually...##
summary(model1)
summary(model2)
summary(model3)
summary(model4)
summary(model5)
summary(model6)

##...or perform ANOVA on all the models at the same time##
anova(model1,model2,model3,model4,model5)

## use the AIC() function to calculate the Akaike information criterion for each model
AIC(model1,model2,model3,model4,model5,model6)

## since model5 appears "best" so far, check its VIF values
vif(model5)

## to reduce the VIFs, center the predictor variables
cLAT <- LAT-mean(LAT)
cLONG <- LONG-mean(LONG)

## run the models again, this time using the centered values
modelc1 <- lm(SQRT_C3~cLONG)
modelc2 <- lm(SQRT_C3~cLAT)
modelc3 <- lm(SQRT_C3~cLONG+cLAT)
modelc4 <- lm(SQRT_C3~cLONG+cLAT+cLONG:cLAT)

## re-compute the AIC values for the centered models
AIC(modelc1,modelc2,modelc3,modelc4)

## perform ANOVA on the models again
anova(modelc1,modelc2,modelc3,modelc4)

## since the full model still appears best, recalculate the VIFs
vif(modelc4)
summary(modelc4)

## Plot three dimension
Y_hats.longlat <- fitted(modelc3)
Y_hats.longxlat <- fitted(modelc4)
library(scatterplot3d)
par(mfrow=c(2,2))
scatter1 <- scatterplot3d(cLONG,cLAT,Y_hats.longlat)
scatter1$plane3d(lm(SQRT_C3~cLONG+cLAT),col="blue")
scatter2 <- scatterplot3d(cLONG,cLAT,Y_hats.longxlat)
scatter1$plane3d(lm(SQRT_C3~cLONG+cLAT),col="blue")
scatter1 <- scatterplot3d(cLAT,cLONG,Y_hats.longlat)
scatter1$plane3d(lm(SQRT_C3~cLAT+cLONG),col="blue")
scatter2 <- scatterplot3d(cLAT,cLONG,Y_hats.longxlat)
scatter1$plane3d(lm(SQRT_C3~cLAT+cLONG),col="blue")
par(mfrow=c(1,1))

## use the step() function to perform backward and forward model stepwise comparisons
step(model, scope=list(lower=SQRT_C3~1,upper=SQRT_C3 ~ MAP+MAT+LONG+LAT+JJAMAP+DJFMAP),direction="forward",data =paruelo_data)
step(model, scope=list(lower=SQRT_C3~1,upper=SQRT_C3 ~ MAP+MAT+LONG+LAT+JJAMAP+DJFMAP),direction="backward",data=paruelo_data)


########## Analysis using WinBUGS##########
library(R2OpenBUGS)

n <- 73
x <- paruelo_data$LONG
w <- paruelo_data$LAT
y <-sqrt(paruelo_data$C3)

# Write model
linreg<-function()

{
  mx <- mean(x[])	# calculate mean of the two explanatory variables
  mw <- mean(w[])

  for (i in 1:73)			# for each of the 73 sites
  {
    Y[i] <- y[i]		# the dependent variable
    Y[i] ~ dnorm(mean[i], prec)	# assume normal distribution
    mean[i] <- a + b[1]*(x[i]-mx) + b[2]*(w[i]-mw) + b[3]*(x[i]-mx)*(w[i]-mw)
  }

  # uninformative priors
  a ~ dnorm(0, 1.0E-6)
  for (i in 1:3)
  {
    b[i] ~ dnorm(0, 1.0E-6)
  }
  prec ~ dgamma(0.001, 0.001)

  for (i in 93:120)
  {
    predlat35[i] <- a + b[1]*(i-mx) + b[2]*(35-mw) + b[3]*(i-mx)*(35-mw)
    predlat45[i] <- a + b[1]*(i-mx) + b[2]*(45-mw) + b[3]*(i-mx)*(45-mw)

    # back-transformed prediction at latitude 35 and 45

    predrichlat35[i] <- (predlat35[i]*predlat35[i])
    predrichlat45[i] <- (predlat45[i]*predlat45[i])
  }

}

write.model(linreg, "linreg.txt")


# Bundle data
win.data <- list("x", "w","y")

# Inits function

inits <- function(){ list(a=runif(1), b=c(runif(1),runif(1),runif(1)),prec = 100)}
# Parameters to estimate
params <- c("a","b","prec","predlat35","predlat45", "predrichlat35","predrichlat45")

# MCMC settings
nc = 1 
ni=10000
nb=100
nt=100

# Start Gibbs sampler
out <- bugs(data = win.data, inits = inits, parameters = params, model = "linreg.txt",
n.thin = nt, n.chains = nc, n.burnin = nb, n.iter = ni, codaPkg=T)

library(coda)
reg.coda<-read.bugs(out)
results<-summary(reg.coda)
restat<-results$statistics
resquant<-results$quantiles

par(mfrow=c(1,2))
###Plotting predicted values of C3 grasses by LONG at different LATs in Bayesian
p <- 93:120
plot(p,restat[7:34,1], type="l",ylim=c(0,1.0),main= "C3 grasses in North America, Bayessian not informed",cex = 1.2, ylab= "relative abundance", xlab =" Longitude", col="blue")
lines(p,resquant[7:34,1],lty=2)
lines(p,resquant[7:34,5],lty=2)
lines(p,restat[35:62,1],type = "l", col = "red", lwd = 1)
lines(p,resquant[35:62,1],lty=2)
lines(p,resquant[35:62,5],lty=2)
points(paruelo_data$LONG[paruelo_data$LAT>33 & paruelo_data$LAT<37],paruelo_data$C3[paruelo_data$LAT>33 & paruelo_data$LAT<37], col="blue")
points(paruelo_data$LONG[paruelo_data$LAT>43 & paruelo_data$LAT<47],paruelo_data$C3[paruelo_data$LAT>43 & paruelo_data$LAT<47], col="red")


###Plotting predicted values of C3 grasses by LONG at different LATs in Frequentist
o <- order(LONG)
a<-sqrt(C3[o])
abc<-lm(a~LAT[o]*LONG[o])
abcpred35<-predict(abc, list(LAT=rep(35, length(LAT)), LONG=LONG), type="response")
abcpred35CI<-predict(abc, list(LAT=rep(35, length(LAT)), LONG=LONG), interval="confidence")
plot(LONG[o],abcpred35, ylim=c(0,1), type="l", col="blue",main= "C3 grasses in North America, Frequentist")
lines(LONG[o],abcpred35CI[,2], lty=3)
lines(LONG[o],abcpred35CI[,3], lty=3)
abcpred45<-predict(abc, list(LAT=rep(45, length(LAT)), LONG=LONG), type="response")
abcpred45CI<-predict(abc, list(LAT=rep(45, length(LAT)), LONG=LONG),  interval="confidence")
lines(LONG[o],abcpred45, col="red")
lines(LONG[o],abcpred45CI[,2],lty=2)
lines(LONG[o],abcpred45CI[,3],lty=2)

par(mfrow=c(1,1))

## detach the data
detach(paruelo_data)
